**Main author:** Ashley Chontos (`email <achontos@hawaii.edu>`_ | `website <https://ashleyin.space>`_)

**All contributors (listed alphabetically):**

* Ashley Chontos (`@ashleychontos <https://github.com/ashleychontos>`_)
* Sam Grayson (`@charmoniumQ <https://github.com/charmoniumQ>`_)
* Daniel Huber (`@danxhuber <https://github.com/danxhuber>`_)
* Maryum Sayeed (`@MaryumSayeed <https://github.com/MaryumSayeed>`_)
* Pavadol Yamsiri (`@pavyamsiri <https://github.com/pavyamsiri>`_)
